This is a plug-in for Thonny which adds BBC micro:bit support. More info about Thonny: http://thonny.org


Plug-in installation and configuration guide: 
https://bitbucket.org/KauriRaba/thonny-microbit/wiki/installation-guide